#
# spec file for package ttyd
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ttyd
Version:        1.7.4
Release:        1.3
Summary:        Share your terminal over the web
License:        MIT
Group:          System/Monitoring
URL:            https://tsl0922.github.io/ttyd/
#Git-Clone:     https://github.com/tsl0922/ttyd.git
Source:         https://github.com/tsl0922/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
# required vim for xxd
BuildRequires:  vim
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(zlib)

%description
Ttyd is a simple command-line tool for sharing terminal over the web, inspired
by GoTTY.

Features include:
 * Built on top of Libwebsockets with C for speed
 * Fully-featured terminal based on Xterm.js with CJK and IME support
 * SSL support based on OpenSSL
 * Run any custom command with options
 * Basic authentication support and many other custom options
 * Cross platform: macOS, Linux, FreeBSD, OpenWrt/LEDE, Windows

%prep
%setup -q

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%{_bindir}/ttyd
%{_mandir}/man1/ttyd.1%{ext_man}

%changelog
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- libwebsockets19 should not be required in specfile
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.4:
  Breaking Changes
  * The default listen interface/ip is changed to 127.0.0.1 now.
  * The web terminal is readonly by default now, to make it
    writable, use -W option.
  Other Changes
  * server: print working directory on start.
  * server: replace --readonly with --writable.
  * server: fix -U option not work.
  * server: do not expose port to public by default.
  * Add -y flag for easier installation.
  * improve support for trzsz.
  * info.max_http_header_data = 65535;
  * fix flow control.
  * Fix typo, OPTOINS -> OPTIONS.
* Sat Sep  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Redeclare requires without using pkgconfig
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Ttyd also requires these packages.
* Fri Feb 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.7.3:
  * server: Custom user/group ownership of Unix domain socket listener, when enabled
  * html: move flow control logic to terminal
  * html: handle binary xterm event
  * html: add option to toggle sixel
  * html: fix trzsz send typo
  * html: add option to toggle trzsz
  * msys2: switch to ucrt64
  * Further information of changes can be found in the link - https://github.com/tsl0922/ttyd/compare/1.6.3...1.7.3
* Sun Jan  3 2021 Martin Hauke <mardnh@gmx.de>
- Updte to version 1.6.3
  * Fixed a crash issue.
  * Added support for xterm flow control.
  * Added a disableReconnect client option.
* Mon Dec 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.2
  * ttyd 1.6.0 is fully event driven by libuv now
  * libwebsockets 3.2 support
  * The index.html is served with gzip now
  * Proxy ttyd under a subpath is supported now
  * Try xterm webgl render with: -t rendererType=webgl
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Zmodem support should be more stable now
  * Error handling of the frontend got a lot of improvements too
* Mon Jun 24 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.0
  * Upstream does not provide a changelog
* Sat Apr 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.3
  * xterm.js 3.12.2
  * server: do not block main thread when acquiring lock
  * server: add support for cli args via url
  * server: use the default ssl_cipher_list
  * html: do not apply winptyCompat addon
  * protocol: exit thread as soon as the command terminate
  * Update max_heaser_data deafult from 4K to 20K
  * protocol: kill process group
  * Close the websocket after forking so that child processes
    don't prevent new connections
  * protocol: cleanup stale thread
  * server: add option to toggle IPv6 support
  * expose term instance to window for programatic use cases
- Update to version 1.4.2
  * This is a bug fix release for 1.4.1.
- Update to version 1.4.1
  * protocol: ignore invalid message
  * html: add development server
  * html: check trailing slash on pathname for ws url
  * xterm.js: 3.6.0
  * libwebsockets 3.0 support
  * protocol: replace sleep with pthread cond
  * server: custom terminal type support
* Thu Jan 18 2018 mardnh@gmx.de
- Update to version 1.4.0
  * protocol: fix host origin checking
  * protocol: fix a regression that may crashes the server
  * protocol: use binary message
  * protocol: avoid extra copy of pty data
  * server: use libwebsockets's built-in ping-pong
  * Removed the --signal-list option
  * Support numeric value for --signal
  * Sync window title with the terminal
  * Replace browserify with webpack
  * Upgraded xterm.js to 3.0.2
  * Added ZMODEM support
* Sat Oct 14 2017 mardnh@gmx.de
- Initial package, version 1.3.3
